/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TIZEN_APPFW_MESSAGE_PORT_COMMOM_H__
#define __TIZEN_APPFW_MESSAGE_PORT_COMMOM_H__

#include <bundle.h>
#include <gio/gio.h>

#include <message_port.h>
#include <message_port_log.h>

#ifdef __cplusplus
extern "C" {
#endif

#define MESSAGEPORT_BUS_NAME_PREFIX "org.tizen.messageport._"
#define MESSAGEPORT_OBJECT_PATH "/org/tizen/messageport"
#define MESSAGEPORT_INTERFACE_PREFIX "org.tizen.messageport._"

#define DBUS_SERVICE_DBUS "org.freedesktop.DBus"
#define DBUS_PATH_DBUS "/org/freedesktop/DBus"
#define DBUS_INTERFACE_DBUS "org.freedesktop.DBus"


#define retvm_if(expr, val, fmt, arg...) do { \
	if (expr) { \
		_LOGE(fmt, ##arg); \
		_LOGE("(%s) -> %s() return", #expr, __func__); \
		return val; \
	} \
} while (0)

#define retv_if(expr, val) do { \
	if (expr) { \
		_LOGE("(%s) -> %s() return", #expr, __func__); \
		return val; \
	} \
} while (0)

#define FREE_AND_NULL(ptr) do { \
	if (ptr) { \
		free((void *)ptr); \
		ptr = NULL; \
	} \
} while (0)

int write_socket(int fd,
		const char *buffer,
		unsigned int nbytes,
		unsigned int *bytes_write,
		int *sequence);
int write_string_to_socket(int fd,
		const char *buffer,
		int string_len,
		unsigned int *bytes_write,
		int *sequence);
int read_socket(int fd,
		char *buffer,
		unsigned int nbytes,
		unsigned int *bytes_read);
int read_string_from_socket(int fd, char **buffer, int *string_len);
bool initialize_common();
bool is_preloaded(const char *local_appid, const char *remote_appid);
int check_certificate(const char *local_appid, const char *remote_appid);
char *get_encoded_name(const char *remote_app_id, const char *port_name, bool is_trusted);
void message_port_lock_mutex();
void message_port_unlock_mutex();

extern bool initialized_common;
extern GDBusConnection *gdbus_conn;
extern char *app_id;

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif /*  __TIZEN_APPFW_MESSAGE_PORT_COMMOM_H__ */
